@@ -38,8 +38,8 @@ if not os.getenv("READ_THE_DOCS"):
 
 
 class FileAPI(API):
-    def __init__(self, query, ingestion, metadata):
-        super().__init__(metadata=metadata, query=query, ingestion=ingestion)
+    def __init__(self, query, ingestion):
+        super().__init__(query=query, ingestion=ingestion)
 
     def list(self):
         """List all the files.
@@ -47,7 +47,7 @@ class FileAPI(API):
         Returns:
            A generator of File protocol messages: the files visible in the project, including metadata.
         """
-        return (file for file in self.query.ListFiles(Empty(), metadata=self.metadata).files)
+        return (file for file in self.query.ListFiles(Empty()).files)
 
     def get(self, file_id: Optional[str] = None, file_name: Optional[str] = None):
         """Get a file by either id or name.
@@ -63,7 +63,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = FileQueryRequest(file=file)
-        return self.query.GetFile(request, metadata=self.metadata)
+        return self.query.GetFile(request)
 
     def get_binary_header(
         self, file_id: Optional[str] = None, file_name: Optional[str] = None, include_raw_header=False
@@ -80,7 +80,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = HeaderFileQueryRequest(file=file, include_raw_header=include_raw_header)
-        return self.query.GetBinaryHeader(request, metadata=self.metadata)
+        return self.query.GetBinaryHeader(request)
 
     def get_text_header(self, file_id: Optional[str] = None, file_name: Optional[str] = None, include_raw_header=False):
         """Get text header of a file by either its id or name.
@@ -95,7 +95,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = HeaderFileQueryRequest(file=file, include_raw_header=include_raw_header)
-        return self.query.GetTextHeader(request, metadata=self.metadata)
+        return self.query.GetTextHeader(request)
 
     def get_file_coverage(
         self,
@@ -118,7 +118,7 @@ class FileAPI(API):
         file = self.identify(file_id, file_name)
         wrapped_crs = {"crs": crs} if crs is not None else None
         request = FileCoverageRequest(file=file, crs=wrapped_crs, in_wkt=in_wkt)
-        return self.query.GetFileDataCoverage(request, metadata=self.metadata)
+        return self.query.GetFileDataCoverage(request)
 
     @staticmethod
     def _verify_input(crs: str = None, wkt: str = None, geo_json: str = None):
@@ -141,7 +141,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = SegYQueryRequest(file=file)
-        return (i for i in self.query.GetSegYFile(request, metadata=self.metadata))
+        return (i for i in self.query.GetSegYFile(request))
 
     def get_segy_by_lines(
         self,
@@ -171,7 +171,7 @@ class FileAPI(API):
         bottom_right = PositionQuery(iline=bottom_right_inline, xline=bottom_right_xline)
         rectangle = LineBasedRectangle(top_left=top_left, bottom_right=bottom_right)
         request = SegYQueryRequest(file=file, lines=rectangle)
-        return (i for i in self.query.GetSegYFile(request, metadata=self.metadata))
+        return (i for i in self.query.GetSegYFile(request))
 
     def get_segy_by_geometry(
         self,
@@ -203,7 +203,7 @@ class FileAPI(API):
             geo = Geometry(crs=CRS(crs=crs), wkt=Wkt(geometry=wkt))
 
         request = SegYQueryRequest(file=file, polygon=geo)
-        return (i for i in self.query.GetSegYFile(request, metadata=self.metadata))
+        return (i for i in self.query.GetSegYFile(request))
 
     def get_line_range(self, file_id: Optional[str] = None, file_name: Optional[str] = None):
         """Get the minimum and maximum xlines and inlines
@@ -217,7 +217,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = FileQueryRequest(file=file)
-        return self.query.GetFileLineRange(request, metadata=self.metadata)
+        return self.query.GetFileLineRange(request)
 
     def get_xlines_by_inline(self, file_id: Optional[str] = None, file_name: Optional[str] = None, inline: int = None):
         """Get the range of xlines by a specific inline
@@ -232,7 +232,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = FileLineQueryRequest(file=file, line=inline)
-        return self.query.GetCrosslinesByInline(request, metadata=self.metadata)
+        return self.query.GetCrosslinesByInline(request)
 
     def get_inlines_by_xline(self, file_id: Optional[str] = None, file_name: Optional[str] = None, xline: int = None):
         """Get the range of inlines by a specific xline
@@ -247,7 +247,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = FileLineQueryRequest(file=file, line=xline)
-        return self.query.GetInlinesByCrossline(request, metadata=self.metadata)
+        return self.query.GetInlinesByCrossline(request)
 
     def register(
         self,
@@ -308,7 +308,7 @@ class FileAPI(API):
             source_group_scalar_override=source_group_scalar_override,
             external_id=external_id,
         )
-        return self.ingestion.RegisterFile(request, metadata=self.metadata)
+        return self.ingestion.RegisterFile(request)
 
     def ingest(
         self,
@@ -336,7 +336,7 @@ class FileAPI(API):
                5: COMPUTE_GRID
 
                6: COMPUTE_TRACE_INDICES
-            storage_tier(str): Optional target storage tier. Leave blank to use the default storage tier. 
+            storage_tier(str): Optional target storage tier. Leave blank to use the default storage tier.
                 EARLY ACCESS: Tiered storage is available in preview for select clients. Tier names and configurations
                 are client specific and not further documented here.
 
@@ -350,7 +350,7 @@ class FileAPI(API):
             request = IngestFileRequest(file=file, target_storage_tier_name=storage_tier)
         else:
             request = IngestFileRequest(file=file, start_step=start_step, target_storage_tier_name=storage_tier)
-        return self.ingestion.IngestFile(request, metadata=self.metadata)
+        return self.ingestion.IngestFile(request)
 
     def delete(self, file_id: Optional[str] = None, file_name: Optional[str] = None, keep_registered: bool = None):
         """Delete a file by either its id or name
@@ -365,7 +365,7 @@ class FileAPI(API):
         """
         file = self.identify(file_id, file_name)
         request = DeleteFileRequest(file=file, keep_registered=keep_registered)
-        return self.ingestion.DeleteFile(request, metadata=self.metadata)
+        return self.ingestion.DeleteFile(request)
 
     def edit(
         self,
@@ -424,7 +424,7 @@ class FileAPI(API):
             source_group_scalar_override=source_group_scalar_override,
             external_id=external_id,
         )
-        return self.ingestion.EditFile(request=request, metadata=self.metadata)
+        return self.ingestion.EditFile(request=request)
 
     @deprecation.deprecated(deprecated_in="0.2.63", details="Multitenant file sharing is not supported anymore")
     def grant_access(
@@ -446,7 +446,7 @@ class FileAPI(API):
         file = self.identify(file_id, file_name)
         project = self.identify(project_id, project_name)
         request = EditFileAccessRequest(file=file, project=project, add=True)
-        self.ingestion.EditFileAccess(request=request, metadata=self.metadata)
+        self.ingestion.EditFileAccess(request=request)
 
     @deprecation.deprecated(deprecated_in="0.2.63", details="Multitenant file sharing is not supported anymore")
     def revoke_access(
@@ -468,4 +468,4 @@ class FileAPI(API):
         file = self.identify(file_id, file_name)
         project = self.identify(project_id, project_name)
         request = EditFileAccessRequest(file=file, project=project, remove=True)
-        self.ingestion.EditFileAccess(request=request, metadata=self.metadata)
+        self.ingestion.EditFileAccess(request=request)
