@@ -37,8 +37,8 @@ else:
 
 
 class SeismicAPI(API):
-    def __init__(self, query, ingestion, metadata):
-        super().__init__(query=query, ingestion=ingestion, metadata=metadata)
+    def __init__(self, query, ingestion):
+        super().__init__(query=query, ingestion=ingestion)
 
     def create(
         self,
@@ -49,7 +49,9 @@ class SeismicAPI(API):
         name: MaybeString = None,
         volumedef: Optional[str] = None,
         geometry: Optional[Geometry] = None,
+        empty: bool = False,
         metadata: Optional[Metadata] = None,
+        copy_metadata: bool = False,
         text_header: Optional[TextHeader] = None,
         binary_header: Optional[BinaryHeader] = None,
     ) -> Seismic:
@@ -64,6 +66,9 @@ class SeismicAPI(API):
             seismic_store_id (int): The seismic store that the new Seismic is derived from
             volumedef (str | None): (Optional) If specified, uses a VolumeDef as the shape of the Seismic
             geometry (Geometry | None): (Optional) If specified, uses a Geometry (either a WKT or GeoJson) as the shape of the Seismic
+            empty (bool): If True, creates an empty seismic with no trace data included.
+            metadata (Dict[str, str] | None): If specified, sets the metadata to the provided value.
+            copy_metadata (bool): If True, ignores the `metadata` arg and copies the metadata from the seismic store.
             text_header (TextHeader | None): (Optional) If specified, sets the provided text header on the new seismic
             binary_header (BinaryHeader | None): (Optional) If specified, sets the provided binary header on the new seismic
 
@@ -82,6 +87,8 @@ class SeismicAPI(API):
             request.volume_def.MergeFrom(VolumeDefPB(json=volumedef))
         elif geometry is not None:
             request.geometry.MergeFrom(geometry.to_proto())
+        elif empty:
+            request.empty = True
 
         if name is not None:
             request.name = name
@@ -89,13 +96,16 @@ class SeismicAPI(API):
         if metadata is not None:
             request.metadata.MergeFrom(OptionalMap(data=metadata))
 
+        if copy_metadata:
+            request.copy_metadata = True
+
         if text_header is not None:
             request.text_header.MergeFrom(text_header.into_proto())
 
         if binary_header is not None:
             request.binary_header.MergeFrom(binary_header.into_proto())
 
-        return Seismic.from_proto(self.query.CreateSeismic(request, metadata=self.metadata))
+        return Seismic.from_proto(self.query.CreateSeismic(request))
 
     def search(
         self,
@@ -177,7 +187,7 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         req.include_seismic_store = include_seismic_store
         req.include_partition = include_partition
 
-        results = self.query.SearchSeismics(req, metadata=self.metadata)
+        results = self.query.SearchSeismics(req)
         for s in results:
             yield Seismic.from_proto(s)
 
@@ -285,7 +295,7 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         if metadata is not None:
             request.metadata.MergeFrom(OptionalMap(data=metadata))
 
-        return Seismic.from_proto(self.query.EditSeismic(request, metadata=self.metadata))
+        return Seismic.from_proto(self.query.EditSeismic(request))
 
     def delete(self, *, id: Union[int, None] = None, external_id: MaybeString = None) -> bool:
         """Delete a seismic
@@ -302,4 +312,4 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         identifier = get_identifier(id, external_id)
         request = DeleteSeismicRequest(seismic=identifier)
 
-        return self.query.DeleteSeismic(request, metadata=self.metadata).succeeded
+        return self.query.DeleteSeismic(request).succeeded
