@@ -35,8 +35,8 @@ if not os.getenv("READ_THE_DOCS"):
 
 
 class SurveyAPI(API):
-    def __init__(self, query, ingestion, metadata):
-        super().__init__(metadata=metadata, query=query, ingestion=ingestion)
+    def __init__(self, query, ingestion):
+        super().__init__(query=query, ingestion=ingestion)
 
     def get(
         self,
@@ -81,7 +81,7 @@ class SurveyAPI(API):
             include_grid_transformation=include_grid_transformation,
             include_custom_coverage=include_custom_coverage,
         )
-        return self.query.GetSurvey(req, metadata=self.metadata)
+        return self.query.GetSurvey(req)
 
     def list(
         self,
@@ -107,8 +107,7 @@ class SurveyAPI(API):
                 include_metadata=include_metadata,
                 include_grid_transformation=include_grid_transformation,
                 include_custom_coverage=include_custom_coverage,
-            ),
-            metadata=self.metadata,
+            )
         )
 
     @staticmethod
@@ -166,7 +165,7 @@ class SurveyAPI(API):
             )
         else:
             request = SearchSurveyRequest(polygon=geo, include_metadata=include_metadata)
-        return self.query.SearchSurveys(request, metadata=self.metadata)
+        return self.query.SearchSurveys(request)
 
     def register(
         self,
@@ -224,7 +223,7 @@ class SurveyAPI(API):
             grid_transformation=survey_grid_transformation_to_proto(grid_transformation),
             custom_coverage=custom_coverage,
         )
-        return self.ingestion.RegisterSurvey(request, metadata=self.metadata)
+        return self.ingestion.RegisterSurvey(request)
 
     def edit(
         self,
@@ -260,7 +259,7 @@ class SurveyAPI(API):
             custom_coverage_geojson (Optional[dict]):
                 Specify a custom coverage polygon for this survey in the geojson format
             clear_custom_coverage (Optional[bool]):
-                Set this to True to clear the custom coverage from this survey, so that coverage is 
+                Set this to True to clear the custom coverage from this survey, so that coverage is
                 computed as a union of the included objects.
 
         Returns:
@@ -289,7 +288,7 @@ class SurveyAPI(API):
             grid_transformation=survey_grid_transformation_to_proto(grid_transformation),
             custom_coverage=custom_coverage,
         )
-        return self.ingestion.EditSurvey(request, metadata=self.metadata)
+        return self.ingestion.EditSurvey(request)
 
     def delete(self, survey_id: Optional[str] = None, survey_name: Optional[str] = None):
         """Delete a survey
@@ -304,4 +303,4 @@ class SurveyAPI(API):
         """
         survey = self.identify(survey_id, survey_name)
         request = DeleteSurveyRequest(survey=survey)
-        return self.ingestion.DeleteSurvey(request, metadata=self.metadata)
+        return self.ingestion.DeleteSurvey(request)
