@@ -4,7 +4,9 @@ import os
 import sys
 import time
 from collections import namedtuple
+from typing import Callable
 
+import certifi
 import deprecation
 import grpc
 from grpc._channel import (
@@ -109,9 +111,32 @@ def decorate_with_wrapped_rpc_errors(*args):
 ParsedUrl = namedtuple("ParsedUrl", "is_insecure target")
 
 
+class ApiKeyAuth(grpc.AuthMetadataPlugin):
+    "Inject the api-key header with an API key in GRPC requests"
+
+    def __init__(self, project_name: str, api_key: str):
+        if project_name is None:
+            self._metadata = (("api-key", api_key),)
+        else:
+            self._metadata = (("api-key", api_key), ("cdf-project-name", project_name))
+
+    def __call__(self, context, callback):
+        callback(self._metadata, None)
+
+
+class BearerTokenAuth(grpc.AuthMetadataPlugin):
+    "Inject an authorization header with a bearer token in GRPC requests"
+
+    def __init__(self, project_name: str, token_supplier: Callable[[], str]):
+        self._project_metadata = ("cdf-project-name", project_name)
+        self._token_supplier = token_supplier
+
+    def __call__(self, context, callback):
+        callback((("authorization", "Bearer " + self._token_supplier()), self._project_metadata), None)
+
+
 def parse_url_parameter(url) -> ParsedUrl:
-    """Parse a provided url, setting the secure/insecure status and standardizing the URL with a port
-    """
+    """Parse a provided url, setting the secure/insecure status and standardizing the URL with a port"""
     from urllib.parse import urlparse
 
     o = urlparse(url)
@@ -133,7 +158,19 @@ def parse_url_parameter(url) -> ParsedUrl:
 
 class CogniteSeismicClient:
     """
-    Main class for the seismic client
+    Main class for the seismic client.
+
+
+    Args:
+        api_key (Optional[str]): An API key. Equivalent to setting the COGNITE_API_KEY environment variable.
+        base_url (Optional[str]): The url to connect to. Defaults to :code:`api.cognitedata.com`.
+        port (Optional[int]): The port to connect to. Defaults to 443.
+        custom_root_cert (Optional[str]): A custom root certificate for SSL connections. Should not need to be used by general users.
+        insecure (bool): If true, will attempt to connect without SSL. Should not be used by general users.
+        project (str): The name of the project to call API endpoints against.
+        no_retries (bool): If true, will not automatically retry failed requests.
+        max_message_size_MB (int): The max message size of gRPC replies. Defaults to 10.
+        oidc_token (Optional[str | Callable[[], str]]): If specified, will attempt to connect to the seismic service using an OIDC token. This should be either a string or a callable.
     """
 
     def __init__(
@@ -146,16 +183,13 @@ class CogniteSeismicClient:
         insecure=False,
         project=None,
         no_retries=False,
+        max_message_size_MB=10,
+        oidc_token=None,
     ):
         # configure env
         self.api_key = api_key or os.getenv("COGNITE_API_KEY")
         self.project = project or os.getenv("COGNITE_PROJECT")
 
-        if self.api_key is None or self.api_key == "":
-            raise ValueError(
-                "You have either not passed an api key or not set the COGNITE_API_KEY environment variable."
-            )
-
         if port is not None or insecure:
             logger.warning("The port and insecure params are deprecated. Please include them in the base_url.")
 
@@ -167,18 +201,47 @@ class CogniteSeismicClient:
             self.target = "api.cognitedata.com:443"
             self.is_insecure = False
 
-        self.metadata = [("api-key", self.api_key)]
+        if self.project is None:
+            if oidc_token is not None:
+                raise ValueError(
+                    "CDF project name must be supplied when using OIDC tokens. Please set the project name with CogniteSeismicClient(project='') or with environment variable COGNITE_PROJECT=''"
+                )
+            else:
+                logger.warning(
+                    "Undefined project name is deprecated behaviour. Please set the project name with CogniteSeismicClient(project='') or with environment variable COGNITE_PROJECT=''"
+                )
 
-        if self.project is not None:
-            self.metadata.append(("cdf-project-name", self.project))
+        if custom_root_cert is None:
+            root_certs = certifi.contents().encode()
         else:
-            logger.warning(
-                "Undefined project name is deprecated behaviour. Please set the project name with CogniteSeismicClient(project='') or with environment variable COGNITE_PROJECT=''"
+            root_certs = custom_root_cert
+
+        if callable(oidc_token):
+            auth_plugin = BearerTokenAuth(self.project, oidc_token)
+        elif oidc_token is not None:
+            auth_plugin = BearerTokenAuth(self.project, lambda: oidc_token)
+        elif self.api_key is not None and self.api_key != "":
+            auth_plugin = ApiKeyAuth(self.project, self.api_key)
+        else:
+            raise ValueError(
+                """
+You must provide at least one of the following:
+* An OIDC token (via the argument 'oidc_token')
+* An API key (via the argument 'api_key')
+* Set the COGNITE_API_KEY environment variable
+            """
             )
 
+        if max_message_size_MB > 10:
+            logger.warning(
+                "Raising the maximum message size above the default of 10MB may result in significant performance costs"
+            )
+        elif max_message_size_MB < 10:
+            raise ValueError("Maximum message size must be at least 10MB")
+
         # start the connection
         options = [
-            ("grpc.max_receive_message_length", 10 * 1024 * 1024),
+            ("grpc.max_receive_message_length", max_message_size_MB * 1024 * 1024),
             ("grpc.keepalive_time_ms", 5000),
             ("grpc.keepalive_permit_without_calls", 1),
             ("grpc.http2.max_pings_without_data", 0),
@@ -187,7 +250,9 @@ class CogniteSeismicClient:
         if self.is_insecure:
             channel = grpc.insecure_channel(self.target, options=options)
         else:
-            credentials = grpc.ssl_channel_credentials(root_certificates=custom_root_cert)
+            credentials = grpc.composite_channel_credentials(
+                grpc.ssl_channel_credentials(root_certificates=root_certs), grpc.metadata_call_credentials(auth_plugin)
+            )
             channel = grpc.secure_channel(self.target, credentials, options=options)
         self.query = query_serv.QueryStub(channel)
         self.ingestion = ingest_serv.IngestStub(channel)
@@ -197,21 +262,21 @@ class CogniteSeismicClient:
             decorate_with_retries(self.query, self.ingestion, self.seismicstub)
         decorate_with_wrapped_rpc_errors(self.query, self.ingestion, self.seismicstub)
 
-        self.survey = SurveyAPI(self.query, self.ingestion, self.metadata)
-        self.file = FileAPI(self.query, self.ingestion, self.metadata)
-        self.trace = TraceAPI(self.query, self.metadata)
-        self.slice = SliceAPI(self.query, self.metadata)
-        self.slab = SlabAPI(self.query, self.file, self.metadata)
-        self.volume = VolumeAPI(self.query, self.ingestion, self.metadata)
-        self.time_slice = TimeSliceAPI(self.query, self.metadata)
-        self.job = JobAPI(self.ingestion, self.metadata)
-        self.survey_v1 = SurveyV1API(self.seismicstub, self.metadata, self.survey)
-        self.volume_seismic = VolumeSeismicAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.partition = PartitionAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.survey = SurveyAPI(self.query, self.ingestion)
+        self.file = FileAPI(self.query, self.ingestion)
+        self.trace = TraceAPI(self.query)
+        self.slice = SliceAPI(self.query)
+        self.slab = SlabAPI(self.query, self.file)
+        self.volume = VolumeAPI(self.query, self.ingestion)
+        self.time_slice = TimeSliceAPI(self.query)
+        self.job = JobAPI(self.ingestion)
+        self.survey_v1 = SurveyV1API(self.seismicstub, self.survey)
+        self.volume_seismic = VolumeSeismicAPI(self.seismicstub, self.ingestion)
+        self.partition = PartitionAPI(self.seismicstub, self.ingestion)
         # The duplicated seismic/seismics is for making the rename backwards compatible.
         # The singular form is the one that we expect to keep after a breaking release.
-        self.seismic = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.seismics = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.seismicstore = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
-        self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self.metadata, self)
+        self.seismic = SeismicAPI(self.seismicstub, self.ingestion)
+        self.seismics = SeismicAPI(self.seismicstub, self.ingestion)
+        self.seismicstore = SeismicStoreAPI(self.seismicstub, self.ingestion)
+        self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion)
+        self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self)
