@@ -903,6 +903,8 @@ class Seismic:
     partition_id: int
     seismicstore_id: Optional[int]
     coverage: Optional[Geometry]
+    created_empty: bool
+    trace_count: int
 
     def __init__(
         self,
@@ -919,6 +921,8 @@ class Seismic:
         partition_id,
         seismicstore_id,
         coverage,
+        created_empty,
+        trace_count,
     ):
         self.id = id
         self.external_id = external_id
@@ -932,6 +936,8 @@ class Seismic:
         self.partition_id = partition_id
         self.seismicstore_id = seismicstore_id
         self.coverage = coverage
+        self.created_empty = created_empty
+        self.trace_count = trace_count
 
     def __repr__(self):
         return f"Seismic<id: {self.id}, external_id: {self.external_id}, name: {self.name}, crs: {self.crs}, metadata: {self.metadata}>"
@@ -972,6 +978,8 @@ class Seismic:
             partition_id=proto.partition_id,
             seismicstore_id=proto.seismicstore_id,
             coverage=coverage,
+            trace_count=proto.trace_count,
+            created_empty=proto.created_empty,
         )
 
 
@@ -981,27 +989,29 @@ class Partition:
     Attributes:
         id (int): The unique internal id for this partition
         name (str): The human-friendly name for this partition
-        seismics (List[:py:class:`Seismic`]): The list of seismics that belong to this partition
+        seismic_ids (List[int]): The list of ids of seismics that belong to this partition
     """
 
     id: int
     external_id: str
     name: str
     seismics: List[Seismic]
+    seismic_ids: List[int]
 
-    def __init__(self, *, id, external_id, name, seismics):
+    def __init__(self, *, id, external_id, name, seismic_ids):
         self.id = id
         self.external_id = external_id
         self.name = name
-        self.seismics = seismics
+        self.seismics = []
+        self.seismic_ids = seismic_ids
 
     def __repr__(self):
         return f"Partition<id: {self.id}, external_id: {self.external_id}, name: {self.name}>"
 
     @staticmethod
     def from_proto(proto) -> "Partition":
-        seismics = [Seismic.from_proto(s) for s in proto.seismics]
-        return Partition(id=proto.id, external_id=proto.external_id, name=proto.name, seismics=seismics)
+        seismic_ids = [i for i in proto.seismic_ids]
+        return Partition(id=proto.id, external_id=proto.external_id, name=proto.name, seismic_ids=seismic_ids)
 
 
 class DoubleTraceCoordinates(NamedTuple):
@@ -1033,7 +1043,7 @@ class DoubleTraceCoordinates(NamedTuple):
 
 class Handedness(Enum):
     """The handedness of a :py:class:`~cognite.seismic.data_classes.api_types.P6Transformation`.
-    RIGHTHANDED means that the inline axis is 90 degrees clockwise from the xline axis. 
+    RIGHTHANDED means that the inline axis is 90 degrees clockwise from the xline axis.
     LEFTHANDED means that the inline axis is 90 degrees counter-clockwise from the xline axis."""
 
     RIGHTHANDED = 0
@@ -1041,7 +1051,7 @@ class Handedness(Enum):
 
 
 class P6Transformation(NamedTuple):
-    """Description of an affine transformation between bin grid coordinates and projected 
+    """Description of an affine transformation between bin grid coordinates and projected
     coordinates in the P6 format, loosely following IOGP guidance note 373-7-2 section 2.3.2.4.
 
     Attributes:
@@ -1130,6 +1140,17 @@ def survey_grid_transformation_from_proto(proto) -> SurveyGridTransformation:
         raise ValueError("Invalid SurveyGridTransformation protobuf")
 
 
+class SurveyCoverageSource(Enum):
+    """Used to request or return that a survey's coverage geometry comes from a specific source. Note: This must be kept in sync with the protobuf representation."""
+
+    UNSPECIFIED = 0
+    """Used as the default when a specific coverage source is not provided"""
+    CUSTOM = 1
+    """Used to specify that a custom coverage should be or was returned"""
+    CALCULATED = 2
+    """Used to specify that a calculated coverage should be or was returned"""
+
+
 class Survey:
 
     id: str
@@ -1142,6 +1163,7 @@ class Survey:
     crs: Optional[str]
     grid_transformation: Optional[SurveyGridTransformation]
     custom_coverage: Optional[Geometry]
+    survey_coverage_source: SurveyCoverageSource
 
     def __init__(
         self,
@@ -1155,6 +1177,7 @@ class Survey:
         crs,
         grid_transformation,
         custom_coverage,
+        survey_coverage_source,
     ):
         self.id = id
         self.external_id = external_id
@@ -1166,6 +1189,7 @@ class Survey:
         self.crs = crs
         self.grid_transformation = grid_transformation
         self.custom_coverage = custom_coverage
+        self.survey_coverage_source = survey_coverage_source
 
     @staticmethod
     def from_proto(proto) -> "Survey":
@@ -1187,6 +1211,10 @@ class Survey:
         else:
             custom_coverage = None
 
+        survey_coverage_source = (
+            proto.coverage_source if hasattr(proto, "coverage_source") else SurveyCoverageSource.UNSPECIFIED
+        )
+
         return Survey(
             survey_id,
             external_id,
@@ -1198,6 +1226,7 @@ class Survey:
             crs,
             grid_transformation,
             custom_coverage,
+            survey_coverage_source,
         )
 
     def __repr__(self):
